@@ -1,31 +1,20 @@
 /*
- *   Copyright 2013 Martin Gräßlin <mgraesslin@kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2013 Martin Gräßlin <mgraesslin@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
+
 #include "nettesthelper.h"
 #include <netwm.h>
-#include <qtest_widgets.h>
+
 #include <QProcess>
+#include <QStandardPaths>
+#include <qtest_widgets.h>
+
 // system
 #include <unistd.h>
 
-class Property : public QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter>
-{
-public:
-    Property(xcb_get_property_reply_t *p = nullptr) : QScopedPointer<xcb_get_property_reply_t, QScopedPointerPodDeleter>(p) {}
-};
+using Property = UniqueCPointer<xcb_get_property_reply_t>;
 
 Q_DECLARE_METATYPE(NET::Orientation)
 Q_DECLARE_METATYPE(NET::DesktopLayoutCorner)
@@ -66,8 +55,8 @@ private:
         return m_connection;
     }
     xcb_connection_t *m_connection;
-    QVector<xcb_connection_t*> m_connections;
-    QScopedPointer<QProcess> m_xvfb;
+    QVector<xcb_connection_t *> m_connections;
+    std::unique_ptr<QProcess> m_xvfb;
     xcb_window_t m_supportWindow;
     xcb_window_t m_rootWindow;
 };
@@ -81,7 +70,6 @@ void NetRootInfoTestWM::cleanupTestCase()
 
 void NetRootInfoTestWM::initTestCase()
 {
-    qsrand(QDateTime::currentMSecsSinceEpoch());
 }
 
 void NetRootInfoTestWM::init()
@@ -90,11 +78,14 @@ void NetRootInfoTestWM::init()
     m_connection = nullptr;
     m_supportWindow = XCB_WINDOW_NONE;
     // start Xvfb
+    const QString xfvbExec = QStandardPaths::findExecutable(QStringLiteral("Xvfb"));
+    QVERIFY(!xfvbExec.isEmpty());
+
     m_xvfb.reset(new QProcess);
     // use pipe to pass fd to Xvfb to get back the display id
     int pipeFds[2];
     QVERIFY(pipe(pipeFds) == 0);
-    m_xvfb->start(QStringLiteral("Xvfb"), QStringList{ QStringLiteral("-displayfd"), QString::number(pipeFds[1]) });
+    m_xvfb->start(xfvbExec, QStringList{QStringLiteral("-displayfd"), QString::number(pipeFds[1])});
     QVERIFY(m_xvfb->waitForStarted());
     QCOMPARE(m_xvfb->state(), QProcess::Running);
 
@@ -107,7 +98,7 @@ void NetRootInfoTestWM::init()
     readPipe.close();
 
     displayNumber.prepend(QByteArray(":"));
-    displayNumber.remove(displayNumber.size() -1, 1);
+    displayNumber.remove(displayNumber.size() - 1, 1);
 
     // create X connection
     int screen = 0;
@@ -116,21 +107,29 @@ void NetRootInfoTestWM::init()
     QVERIFY(!xcb_connection_has_error(m_connection));
     m_rootWindow = KXUtils::rootWindow(m_connection, screen);
     uint32_t values[] = {XCB_EVENT_MASK_PROPERTY_CHANGE};
-    xcb_change_window_attributes(m_connection, m_rootWindow,
-                                 XCB_CW_EVENT_MASK, values);
+    xcb_change_window_attributes(m_connection, m_rootWindow, XCB_CW_EVENT_MASK, values);
 
     // create support window
     values[0] = true;
     m_supportWindow = xcb_generate_id(m_connection);
-    xcb_create_window(m_connection, XCB_COPY_FROM_PARENT, m_supportWindow,
+    xcb_create_window(m_connection,
+                      XCB_COPY_FROM_PARENT,
+                      m_supportWindow,
                       m_rootWindow,
-                      0, 0, 1, 1, 0, XCB_COPY_FROM_PARENT,
-                      XCB_COPY_FROM_PARENT, XCB_CW_OVERRIDE_REDIRECT, values);
-    const uint32_t lowerValues[] = { XCB_STACK_MODE_BELOW };
+                      0,
+                      0,
+                      1,
+                      1,
+                      0,
+                      XCB_COPY_FROM_PARENT,
+                      XCB_COPY_FROM_PARENT,
+                      XCB_CW_OVERRIDE_REDIRECT,
+                      values);
+    const uint32_t lowerValues[] = {XCB_STACK_MODE_BELOW};
     // we need to do the lower window with a roundtrip, otherwise NETRootInfo is not functioning
-    QScopedPointer<xcb_generic_error_t, QScopedPointerPodDeleter> error(xcb_request_check(m_connection,
-            xcb_configure_window_checked(m_connection, m_supportWindow, XCB_CONFIG_WINDOW_STACK_MODE, lowerValues)));
-    QVERIFY(error.isNull());
+    UniqueCPointer<xcb_generic_error_t> error(
+        xcb_request_check(m_connection, xcb_configure_window_checked(m_connection, m_supportWindow, XCB_CONFIG_WINDOW_STACK_MODE, lowerValues)));
+    QVERIFY(!error);
 }
 
 void NetRootInfoTestWM::cleanup()
@@ -151,14 +150,14 @@ void NetRootInfoTestWM::cleanup()
 void NetRootInfoTestWM::waitForPropertyChange(NETRootInfo *info, xcb_atom_t atom, NET::Property prop, NET::Property2 prop2)
 {
     while (true) {
-        KXUtils::ScopedCPointer<xcb_generic_event_t> event(xcb_wait_for_event(connection()));
-        if (event.isNull()) {
+        UniqueCPointer<xcb_generic_event_t> event(xcb_wait_for_event(connection()));
+        if (!event) {
             break;
         }
         if ((event->response_type & ~0x80) != XCB_PROPERTY_NOTIFY) {
             continue;
         }
-        xcb_property_notify_event_t *pe = reinterpret_cast<xcb_property_notify_event_t *>(event.data());
+        xcb_property_notify_event_t *pe = reinterpret_cast<xcb_property_notify_event_t *>(event.get());
         if (pe->window != m_rootWindow) {
             continue;
         }
@@ -167,7 +166,7 @@ void NetRootInfoTestWM::waitForPropertyChange(NETRootInfo *info, xcb_atom_t atom
         }
         NET::Properties dirty;
         NET::Properties2 dirty2;
-        info->event(event.data(), &dirty, &dirty2);
+        info->event(event.get(), &dirty, &dirty2);
         if (prop != 0) {
             QVERIFY(dirty & prop);
         }
@@ -187,8 +186,8 @@ void NetRootInfoTestWM::waitForPropertyChange(NETRootInfo *info, xcb_atom_t atom
 void NetRootInfoTestWM::testCtor()
 {
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QCOMPARE(rootInfo.xcbConnection(), connection());
     QCOMPARE(rootInfo.rootWindow(), m_rootWindow);
     QCOMPARE(rootInfo.supportWindow(), m_supportWindow);
@@ -213,10 +212,10 @@ void NetRootInfoTestWM::testSupported()
     KXUtils::Atom wmName(connection(), QByteArrayLiteral("_NET_WM_NAME"));
     KXUtils::Atom utf8String(connection(), QByteArrayLiteral("UTF8_STRING"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     int count = 0;
-    for (int i = 0; i < 33; ++i) {
+    for (int i = 0; i < 34; ++i) {
         if (i == 12) {
             continue;
         }
@@ -245,48 +244,46 @@ void NetRootInfoTestWM::testSupported()
     count -= 7;
     // WM2BlockCompositing has 3 properties
     count += 2;
+    // Add _GTK_FRAME_EXTENTS
+    ++count;
 
-    QVERIFY(supported  != XCB_ATOM_NONE);
+    QVERIFY(supported != XCB_ATOM_NONE);
     QVERIFY(utf8String != XCB_ATOM_NONE);
-    QVERIFY(wmCheck    != XCB_ATOM_NONE);
-    QVERIFY(wmName     != XCB_ATOM_NONE);
+    QVERIFY(wmCheck != XCB_ATOM_NONE);
+    QVERIFY(wmName != XCB_ATOM_NONE);
 
     // we should have got some events
     waitForPropertyChange(&rootInfo, supported, NET::Supported);
     waitForPropertyChange(&rootInfo, wmCheck, NET::SupportingWMCheck);
 
     // get the cookies of the things to check
-    xcb_get_property_cookie_t supportedCookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-            supported, XCB_ATOM_ATOM, 0, 101);
-    xcb_get_property_cookie_t wmCheckRootCookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-            wmCheck, XCB_ATOM_WINDOW, 0, 1);
-    xcb_get_property_cookie_t wmCheckSupportWinCookie = xcb_get_property_unchecked(connection(), false, m_supportWindow,
-            wmCheck, XCB_ATOM_WINDOW, 0, 1);
-    xcb_get_property_cookie_t  wmNameCookie = xcb_get_property_unchecked(connection(), false, m_supportWindow,
-            wmName, utf8String, 0, 16);
+    xcb_get_property_cookie_t supportedCookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), supported, XCB_ATOM_ATOM, 0, 101);
+    xcb_get_property_cookie_t wmCheckRootCookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), wmCheck, XCB_ATOM_WINDOW, 0, 1);
+    xcb_get_property_cookie_t wmCheckSupportWinCookie = xcb_get_property_unchecked(connection(), false, m_supportWindow, wmCheck, XCB_ATOM_WINDOW, 0, 1);
+    xcb_get_property_cookie_t wmNameCookie = xcb_get_property_unchecked(connection(), false, m_supportWindow, wmName, utf8String, 0, 16);
 
     Property supportedReply(xcb_get_property_reply(connection(), supportedCookie, nullptr));
-    QVERIFY(!supportedReply.isNull());
+    QVERIFY(supportedReply);
     QCOMPARE(supportedReply->format, uint8_t(32));
     QCOMPARE(supportedReply->value_len, uint32_t(count));
     // TODO: check that the correct atoms are set?
     Property wmCheckRootReply(xcb_get_property_reply(connection(), wmCheckRootCookie, nullptr));
-    QVERIFY(!wmCheckRootReply.isNull());
+    QVERIFY(wmCheckRootReply);
     QCOMPARE(wmCheckRootReply->format, uint8_t(32));
     QCOMPARE(wmCheckRootReply->value_len, uint32_t(1));
-    QCOMPARE(reinterpret_cast<xcb_window_t *>(xcb_get_property_value(wmCheckRootReply.data()))[0], m_supportWindow);
+    QCOMPARE(reinterpret_cast<xcb_window_t *>(xcb_get_property_value(wmCheckRootReply.get()))[0], m_supportWindow);
 
     Property wmCheckSupportReply(xcb_get_property_reply(connection(), wmCheckSupportWinCookie, nullptr));
-    QVERIFY(!wmCheckSupportReply.isNull());
+    QVERIFY(wmCheckSupportReply);
     QCOMPARE(wmCheckSupportReply->format, uint8_t(32));
     QCOMPARE(wmCheckSupportReply->value_len, uint32_t(1));
-    QCOMPARE(reinterpret_cast<xcb_window_t *>(xcb_get_property_value(wmCheckSupportReply.data()))[0], m_supportWindow);
+    QCOMPARE(reinterpret_cast<xcb_window_t *>(xcb_get_property_value(wmCheckSupportReply.get()))[0], m_supportWindow);
 
     Property wmNameReply(xcb_get_property_reply(connection(), wmNameCookie, nullptr));
-    QVERIFY(!wmNameReply.isNull());
+    QVERIFY(wmNameReply);
     QCOMPARE(wmNameReply->format, uint8_t(8));
     QCOMPARE(wmNameReply->value_len, uint32_t(15));
-    QCOMPARE(reinterpret_cast<const char *>(xcb_get_property_value(wmNameReply.data())), s_wmName);
+    QCOMPARE(reinterpret_cast<const char *>(xcb_get_property_value(wmNameReply.get())), s_wmName);
 
     // disable some supported
     rootInfo.setSupported(NET::WMFrameExtents, false);
@@ -308,10 +305,9 @@ void NetRootInfoTestWM::testSupported()
     QVERIFY(rootInfo.isSupported(NET::DockMask));
 
     // lets get supported again
-    supportedCookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                      supported, XCB_ATOM_ATOM, 0, 90);
+    supportedCookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), supported, XCB_ATOM_ATOM, 0, 90);
     supportedReply.reset(xcb_get_property_reply(connection(), supportedCookie, nullptr));
-    QVERIFY(!supportedReply.isNull());
+    QVERIFY(supportedReply);
     QCOMPARE(supportedReply->format, uint8_t(32));
     QCOMPARE(supportedReply->value_len, uint32_t(count - 7));
 
@@ -324,10 +320,9 @@ void NetRootInfoTestWM::testSupported()
     // turn something off, just to get another event
     rootInfo.setSupported(NET::WM2BlockCompositing, false);
     // lets get supported again
-    supportedCookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                      supported, XCB_ATOM_ATOM, 0, 90);
+    supportedCookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), supported, XCB_ATOM_ATOM, 0, 90);
     supportedReply.reset(xcb_get_property_reply(connection(), supportedCookie, nullptr));
-    QVERIFY(!supportedReply.isNull());
+    QVERIFY(supportedReply);
     QCOMPARE(supportedReply->format, uint8_t(32));
     QCOMPARE(supportedReply->value_len, uint32_t(count - 9));
     NETRootInfo clientInfo(connection(), NET::Supported | NET::SupportingWMCheck);
@@ -339,8 +334,8 @@ void NetRootInfoTestWM::testClientList()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_CLIENT_LIST"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QCOMPARE(rootInfo.clientListCount(), 0);
     QVERIFY(!rootInfo.clientList());
 
@@ -348,8 +343,7 @@ void NetRootInfoTestWM::testClientList()
                               xcb_generate_id(connection()),
                               xcb_generate_id(connection()),
                               xcb_generate_id(connection()),
-                              xcb_generate_id(connection())
-                             };
+                              xcb_generate_id(connection())};
     rootInfo.setClientList(windows, 5);
     QCOMPARE(rootInfo.clientListCount(), 5);
     const xcb_window_t *otherWins = rootInfo.clientList();
@@ -359,13 +353,12 @@ void NetRootInfoTestWM::testClientList()
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_WINDOW, 0, 5);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_WINDOW, 0, 5);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(5));
-    const xcb_window_t *propWins = reinterpret_cast<xcb_window_t *>(xcb_get_property_value(reply.data()));
+    const xcb_window_t *propWins = reinterpret_cast<xcb_window_t *>(xcb_get_property_value(reply.get()));
     for (int i = 0; i < 5; ++i) {
         QCOMPARE(propWins[i], windows[i]);
     }
@@ -384,8 +377,8 @@ void NetRootInfoTestWM::testClientListStacking()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_CLIENT_LIST_STACKING"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QCOMPARE(rootInfo.clientListStackingCount(), 0);
     QVERIFY(!rootInfo.clientListStacking());
 
@@ -393,8 +386,7 @@ void NetRootInfoTestWM::testClientListStacking()
                               xcb_generate_id(connection()),
                               xcb_generate_id(connection()),
                               xcb_generate_id(connection()),
-                              xcb_generate_id(connection())
-                             };
+                              xcb_generate_id(connection())};
     rootInfo.setClientListStacking(windows, 5);
     QCOMPARE(rootInfo.clientListStackingCount(), 5);
     const xcb_window_t *otherWins = rootInfo.clientListStacking();
@@ -404,13 +396,12 @@ void NetRootInfoTestWM::testClientListStacking()
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_WINDOW, 0, 5);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_WINDOW, 0, 5);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(5));
-    const xcb_window_t *propWins = reinterpret_cast<xcb_window_t *>(xcb_get_property_value(reply.data()));
+    const xcb_window_t *propWins = reinterpret_cast<xcb_window_t *>(xcb_get_property_value(reply.get()));
     for (int i = 0; i < 5; ++i) {
         QCOMPARE(propWins[i], windows[i]);
     }
@@ -428,8 +419,8 @@ void NetRootInfoTestWM::testVirtualRoots()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_VIRTUAL_ROOTS"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QCOMPARE(rootInfo.virtualRootsCount(), 0);
     QVERIFY(!rootInfo.virtualRoots());
 
@@ -437,8 +428,7 @@ void NetRootInfoTestWM::testVirtualRoots()
                               xcb_generate_id(connection()),
                               xcb_generate_id(connection()),
                               xcb_generate_id(connection()),
-                              xcb_generate_id(connection())
-                             };
+                              xcb_generate_id(connection())};
     rootInfo.setVirtualRoots(windows, 5);
     QCOMPARE(rootInfo.virtualRootsCount(), 5);
     const xcb_window_t *otherWins = rootInfo.virtualRoots();
@@ -448,13 +438,12 @@ void NetRootInfoTestWM::testVirtualRoots()
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_WINDOW, 0, 5);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_WINDOW, 0, 5);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(5));
-    const xcb_window_t *propWins = reinterpret_cast<xcb_window_t *>(xcb_get_property_value(reply.data()));
+    const xcb_window_t *propWins = reinterpret_cast<xcb_window_t *>(xcb_get_property_value(reply.get()));
     for (int i = 0; i < 5; ++i) {
         QCOMPARE(propWins[i], windows[i]);
     }
@@ -473,21 +462,20 @@ void NetRootInfoTestWM::testNumberOfDesktops()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_NUMBER_OF_DESKTOPS"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QCOMPARE(rootInfo.numberOfDesktops(), 1);
     rootInfo.setNumberOfDesktops(4);
     QCOMPARE(rootInfo.numberOfDesktops(), 4);
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_CARDINAL, 0, 1);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_CARDINAL, 0, 1);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(1));
-    QCOMPARE(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()))[0], uint32_t(4));
+    QCOMPARE(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()))[0], uint32_t(4));
 
     // wait for our property
     waitForPropertyChange(&rootInfo, atom, NET::NumberOfDesktops);
@@ -499,22 +487,21 @@ void NetRootInfoTestWM::testCurrentDesktop()
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_CURRENT_DESKTOP"));
     // TODO: verify that current desktop cannot be higher than number of desktops
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QCOMPARE(rootInfo.currentDesktop(), 1);
     rootInfo.setCurrentDesktop(5);
     QCOMPARE(rootInfo.currentDesktop(), 5);
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_CARDINAL, 0, 1);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_CARDINAL, 0, 1);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(1));
     // note: API starts counting at 1, but property starts counting at 5, because of that subtracting one
-    QCOMPARE(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()))[0], uint32_t(5 - 1));
+    QCOMPARE(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()))[0], uint32_t(5 - 1));
 
     // wait for our property
     waitForPropertyChange(&rootInfo, atom, NET::CurrentDesktop);
@@ -526,8 +513,8 @@ void NetRootInfoTestWM::testDesktopNames()
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_DESKTOP_NAMES"));
     KXUtils::Atom utf8String(connection(), QByteArrayLiteral("UTF8_STRING"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QVERIFY(!rootInfo.desktopName(0));
     QVERIFY(!rootInfo.desktopName(1));
     QVERIFY(!rootInfo.desktopName(2));
@@ -540,13 +527,12 @@ void NetRootInfoTestWM::testDesktopNames()
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
     QVERIFY(utf8String != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, utf8String, 0, 10000);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, utf8String, 0, 10000);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(8));
     QCOMPARE(reply->value_len, uint32_t(8));
-    QCOMPARE(reinterpret_cast<const char *>(xcb_get_property_value(reply.data())), "foo\0bar");
+    QCOMPARE(reinterpret_cast<const char *>(xcb_get_property_value(reply.get())), "foo\0bar");
 
     // wait for our property
     waitForPropertyChange(&rootInfo, atom, NET::DesktopNames);
@@ -562,8 +548,8 @@ void NetRootInfoTestWM::testActiveWindow()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_ACTIVE_WINDOW"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QVERIFY(rootInfo.activeWindow() == XCB_WINDOW_NONE);
     // rootinfo doesn't verify whether our window is a window, so we just generate an ID
     xcb_window_t activeWindow = xcb_generate_id(connection());
@@ -572,13 +558,12 @@ void NetRootInfoTestWM::testActiveWindow()
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_WINDOW, 0, 1);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_WINDOW, 0, 1);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(1));
-    QCOMPARE(reinterpret_cast<xcb_window_t *>(xcb_get_property_value(reply.data()))[0], activeWindow);
+    QCOMPARE(reinterpret_cast<xcb_window_t *>(xcb_get_property_value(reply.get()))[0], activeWindow);
 
     // wait for our property
     waitForPropertyChange(&rootInfo, atom, NET::ActiveWindow);
@@ -589,8 +574,8 @@ void NetRootInfoTestWM::testDesktopGeometry()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_DESKTOP_GEOMETRY"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QCOMPARE(rootInfo.desktopGeometry().width, 0);
     QCOMPARE(rootInfo.desktopGeometry().height, 0);
 
@@ -603,13 +588,12 @@ void NetRootInfoTestWM::testDesktopGeometry()
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_CARDINAL, 0, 2);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_CARDINAL, 0, 2);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(2));
-    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()));
+    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()));
     QCOMPARE(data[0], uint32_t(size.width));
     QCOMPARE(data[1], uint32_t(size.height));
 
@@ -629,18 +613,18 @@ void NetRootInfoTestWM::testDesktopLayout_data()
     QTest::newRow("h/1/0/tr") << NET::OrientationHorizontal << QSize(1, 0) << NET::DesktopLayoutCornerTopRight;
     QTest::newRow("h/0/1/bl") << NET::OrientationHorizontal << QSize(0, 1) << NET::DesktopLayoutCornerBottomLeft;
     QTest::newRow("h/1/2/br") << NET::OrientationHorizontal << QSize(1, 2) << NET::DesktopLayoutCornerBottomRight;
-    QTest::newRow("v/3/2/tl") << NET::OrientationVertical   << QSize(3, 2) << NET::DesktopLayoutCornerTopLeft;
-    QTest::newRow("v/5/4/tr") << NET::OrientationVertical   << QSize(5, 4) << NET::DesktopLayoutCornerTopRight;
-    QTest::newRow("v/2/1/bl") << NET::OrientationVertical   << QSize(2, 1) << NET::DesktopLayoutCornerBottomLeft;
-    QTest::newRow("v/3/2/br") << NET::OrientationVertical   << QSize(3, 2) << NET::DesktopLayoutCornerBottomRight;
+    QTest::newRow("v/3/2/tl") << NET::OrientationVertical << QSize(3, 2) << NET::DesktopLayoutCornerTopLeft;
+    QTest::newRow("v/5/4/tr") << NET::OrientationVertical << QSize(5, 4) << NET::DesktopLayoutCornerTopRight;
+    QTest::newRow("v/2/1/bl") << NET::OrientationVertical << QSize(2, 1) << NET::DesktopLayoutCornerBottomLeft;
+    QTest::newRow("v/3/2/br") << NET::OrientationVertical << QSize(3, 2) << NET::DesktopLayoutCornerBottomRight;
 }
 
 void NetRootInfoTestWM::testDesktopLayout()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_DESKTOP_LAYOUT"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QFETCH(NET::Orientation, orientation);
     QFETCH(QSize, columnsRows);
     QFETCH(NET::DesktopLayoutCorner, corner);
@@ -652,13 +636,12 @@ void NetRootInfoTestWM::testDesktopLayout()
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_CARDINAL, 0, 4);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_CARDINAL, 0, 4);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(4));
-    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()));
+    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()));
     QCOMPARE(data[0], uint32_t(orientation));
     QCOMPARE(data[1], uint32_t(columnsRows.width()));
     QCOMPARE(data[2], uint32_t(columnsRows.height()));
@@ -678,8 +661,8 @@ void NetRootInfoTestWM::testDesktopViewports()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_DESKTOP_VIEWPORT"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     // we need to know the number of desktops, therefore setting it
     rootInfo.setNumberOfDesktops(4);
     NETPoint desktopOne;
@@ -706,13 +689,12 @@ void NetRootInfoTestWM::testDesktopViewports()
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_CARDINAL, 0, 8);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_CARDINAL, 0, 8);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(8));
-    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()));
+    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()));
     QCOMPARE(data[0], uint32_t(desktopOne.x));
     QCOMPARE(data[1], uint32_t(desktopOne.y));
     QCOMPARE(data[2], uint32_t(desktopTwo.x));
@@ -741,7 +723,7 @@ void NetRootInfoTestWM::testShowingDesktop_data()
     QTest::addColumn<bool>("set");
     QTest::addColumn<uint32_t>("setValue");
 
-    QTest::newRow("true")  << true  << uint32_t(1);
+    QTest::newRow("true") << true << uint32_t(1);
     QTest::newRow("false") << false << uint32_t(0);
 }
 
@@ -749,21 +731,20 @@ void NetRootInfoTestWM::testShowingDesktop()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_SHOWING_DESKTOP"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     QFETCH(bool, set);
     rootInfo.setShowingDesktop(set);
     QCOMPARE(rootInfo.showingDesktop(), set);
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_CARDINAL, 0, 1);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_CARDINAL, 0, 1);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(1));
-    QTEST(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()))[0], "setValue");
+    QTEST(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()))[0], "setValue");
 
     // wait for our property
     waitForPropertyChange(&rootInfo, atom, NET::Property(0), NET::WM2ShowingDesktop);
@@ -774,8 +755,8 @@ void NetRootInfoTestWM::testWorkArea()
 {
     KXUtils::Atom atom(connection(), QByteArrayLiteral("_NET_WORKAREA"));
     QVERIFY(connection());
-    NETRootInfo rootInfo(connection(), m_supportWindow, s_wmName,
-                         NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
+    NETRootInfo
+        rootInfo(connection(), m_supportWindow, s_wmName, NET::WMAllProperties, NET::AllTypesMask, NET::States(~0u), NET::WM2AllProperties, NET::Actions(~0u));
     // we need to know the number of desktops, therefore setting it
     rootInfo.setNumberOfDesktops(4);
     NETRect desktopOne;
@@ -814,23 +795,22 @@ void NetRootInfoTestWM::testWorkArea()
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
-    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(),
-                                       atom, XCB_ATOM_CARDINAL, 0, 16);
+    xcb_get_property_cookie_t cookie = xcb_get_property_unchecked(connection(), false, rootInfo.rootWindow(), atom, XCB_ATOM_CARDINAL, 0, 16);
     Property reply(xcb_get_property_reply(connection(), cookie, nullptr));
-    QVERIFY(!reply.isNull());
+    QVERIFY(reply);
     QCOMPARE(reply->format, uint8_t(32));
     QCOMPARE(reply->value_len, uint32_t(16));
-    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()));
-    QCOMPARE(data[ 0], uint32_t(desktopOne.pos.x));
-    QCOMPARE(data[ 1], uint32_t(desktopOne.pos.y));
-    QCOMPARE(data[ 2], uint32_t(desktopOne.size.width));
-    QCOMPARE(data[ 3], uint32_t(desktopOne.size.height));
-    QCOMPARE(data[ 4], uint32_t(desktopTwo.pos.x));
-    QCOMPARE(data[ 5], uint32_t(desktopTwo.pos.y));
-    QCOMPARE(data[ 6], uint32_t(desktopTwo.size.width));
-    QCOMPARE(data[ 7], uint32_t(desktopTwo.size.height));
-    QCOMPARE(data[ 8], uint32_t(0));
-    QCOMPARE(data[ 9], uint32_t(0));
+    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.get()));
+    QCOMPARE(data[0], uint32_t(desktopOne.pos.x));
+    QCOMPARE(data[1], uint32_t(desktopOne.pos.y));
+    QCOMPARE(data[2], uint32_t(desktopOne.size.width));
+    QCOMPARE(data[3], uint32_t(desktopOne.size.height));
+    QCOMPARE(data[4], uint32_t(desktopTwo.pos.x));
+    QCOMPARE(data[5], uint32_t(desktopTwo.pos.y));
+    QCOMPARE(data[6], uint32_t(desktopTwo.size.width));
+    QCOMPARE(data[7], uint32_t(desktopTwo.size.height));
+    QCOMPARE(data[8], uint32_t(0));
+    QCOMPARE(data[9], uint32_t(0));
     QCOMPARE(data[10], uint32_t(0));
     QCOMPARE(data[11], uint32_t(0));
     QCOMPARE(data[12], uint32_t(0));
